@@ -89,11 +89,11 @@ void ConferenceEditor::itemSelected(const QModelIndex& current, const QModelInde
 
         conferenceTitle->setText(conf.title());
         conferenceSubtitle->setText(conf.subtitle());
-        conferenceWhere->setText(conf.city() + ", " + conf.venue());
+        conferenceWhere->setText(conf.city() + (!conf.venue().isEmpty() ? ", " + conf.venue() : ""));
         conferenceWhen->setText(
-                conf.start().toString("dd-MM-yyyy")
-                + ", " +
-                conf.end().toString("dd-MM-yyyy"));
+                conf.start().toString("yyyy-MM-dd")
+                + " - " +
+                conf.end().toString("yyyy-MM-dd"));
         conferenceInfo->setCurrentIndex(0);
         removeBtn->show();
     }
